# IO.Swagger.Api.CustomerApi

All URIs are relative to *https://reputationcrm.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**CreateCustomerAutomatic**](CustomerApi.md#createcustomerautomatic) | **POST** /createCustomerAutomatic | Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (No delay before sending the First Feedback / Review Request)
[**CreateCustomerAutomaticWithDelayReviewRequest**](CustomerApi.md#createcustomerautomaticwithdelayreviewrequest) | **POST** /createCustomerAutomaticWithDelayReviewRequest | Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (Set a Delay before sending the First Feedback / Review Request)
[**CreateCustomerImmediateFirstReviewRequest**](CustomerApi.md#createcustomerimmediatefirstreviewrequest) | **POST** /createCustomerImmediateFirstReviewRequest | Create a Customer AND Feedback / Review Requests
[**CreateCustomerManualScheduleOneReviewRequest**](CustomerApi.md#createcustomermanualscheduleonereviewrequest) | **POST** /createCustomerManualScheduleOneReviewRequest | Create a Customer AND a one Feedback / Review Request (Manual Scheduling)
[**DeleteCustomer**](CustomerApi.md#deletecustomer) | **DELETE** /deleteCustomer | Delete ONE Customer record
[**GetAllCustomersBycompanyId**](CustomerApi.md#getallcustomersbycompanyid) | **GET** /getAllCustomersBycompanyId | Get Information on ALL Customers of a Company / Location / Feedback Page
[**GetCustomersWhoHaveNotYetSubmittedReview**](CustomerApi.md#getcustomerswhohavenotyetsubmittedreview) | **GET** /getCustomersWhoHaveNotYetSubmittedReview | Get a list of Customers who have not yet submitted their Review / Feedback
[**GetSingleCustomer**](CustomerApi.md#getsinglecustomer) | **GET** /getSingleCustomer | Get Information of ONE Customer
[**UpdateCustomer**](CustomerApi.md#updatecustomer) | **PUT** /updateCustomer | Update the record of ONE Customer


<a name="createcustomerautomatic"></a>
# **CreateCustomerAutomatic**
> string CreateCustomerAutomatic (string companyid, string firstname, string lastname, string sendtype, string email, string mobile, string address, string zipcode, string city, string state, string country, string language, string notes)

Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (No delay before sending the First Feedback / Review Request)

This API call creates a Customer in Reputation Builder, AND schedules an Automatic Email AND / OR SMS Feedback / Review Request Sequence, WITH NO DELAY BEFORE SENDING THE FIRST FEEDBACK / REVIEW REQUEST, based on settings of the Company / Location -> Notifications -> Email AND SMS Tabs 

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class CreateCustomerAutomaticExample
    {
        public void main()
        {
            
            // Configure API key authorization: api_key
            Configuration.Default.ApiKey.Add("key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("key", "Bearer");

            var apiInstance = new CustomerApi();
            var companyid = companyid_example;  // string | Company ID
            var firstname = firstname_example;  // string | Customer First Name
            var lastname = lastname_example;  // string | Customer Last Name
            var sendtype = sendtype_example;  // string | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\"  (default to 1)
            var email = email_example;  // string | Customer Email (optional) 
            var mobile = mobile_example;  // string | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  (optional) 
            var address = address_example;  // string | Customer Postal Address (optional) 
            var zipcode = zipcode_example;  // string | Customer Zipcode (optional) 
            var city = city_example;  // string | Customer City (optional) 
            var state = state_example;  // string | Customer State / Province / Region (optional) 
            var country = country_example;  // string | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  (optional) 
            var language = language_example;  // string | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  (optional) 
            var notes = notes_example;  // string | Additional Customer Notes (optional) 

            try
            {
                // Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (No delay before sending the First Feedback / Review Request)
                string result = apiInstance.CreateCustomerAutomatic(companyid, firstname, lastname, sendtype, email, mobile, address, zipcode, city, state, country, language, notes);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling CustomerApi.CreateCustomerAutomatic: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 
 **firstname** | **string**| Customer First Name | 
 **lastname** | **string**| Customer Last Name | 
 **sendtype** | **string**| Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot;  | [default to 1]
 **email** | **string**| Customer Email | [optional] 
 **mobile** | **string**| Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  | [optional] 
 **address** | **string**| Customer Postal Address | [optional] 
 **zipcode** | **string**| Customer Zipcode | [optional] 
 **city** | **string**| Customer City | [optional] 
 **state** | **string**| Customer State / Province / Region | [optional] 
 **country** | **string**| Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  | [optional] 
 **language** | **string**| Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  | [optional] 
 **notes** | **string**| Additional Customer Notes | [optional] 

### Return type

**string**

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="createcustomerautomaticwithdelayreviewrequest"></a>
# **CreateCustomerAutomaticWithDelayReviewRequest**
> void CreateCustomerAutomaticWithDelayReviewRequest (string companyid, string firstname, string lastname, string sendtype, string delayBeforeFirstReviewRequest, string email, string mobile, string address, string zipcode, string city, string state, string country, string language, string notes)

Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (Set a Delay before sending the First Feedback / Review Request)

This API call creates a Customer in Reputation Builder, AND schedules an Automatic Email AND / OR SMS Feedback / Review Request Sequence, WITH A DELAY BEFORE SENDING THE FIRST FEEDBACK / REVIEW REQUEST, based on settings of the Company / Location -> Notifications -> Email AND SMS Tabs 

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class CreateCustomerAutomaticWithDelayReviewRequestExample
    {
        public void main()
        {
            
            // Configure API key authorization: api_key
            Configuration.Default.ApiKey.Add("key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("key", "Bearer");

            var apiInstance = new CustomerApi();
            var companyid = companyid_example;  // string | Company ID
            var firstname = firstname_example;  // string | Customer First Name
            var lastname = lastname_example;  // string | Customer Last Name
            var sendtype = sendtype_example;  // string | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\"  (default to 1)
            var delayBeforeFirstReviewRequest = delayBeforeFirstReviewRequest_example;  // string | Delay before sending the first Feedback / Review Request (Allowed values: \"immediately\", \"X minute\", \"X hour\", \"X day\", \"X week\", \"X month\", \"X year\") 
            var email = email_example;  // string | Customer Email (optional) 
            var mobile = mobile_example;  // string | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  (optional) 
            var address = address_example;  // string | Customer Postal Address (optional) 
            var zipcode = zipcode_example;  // string | Customer Zipcode (optional) 
            var city = city_example;  // string | Customer City (optional) 
            var state = state_example;  // string | Customer State / Province / Region (optional) 
            var country = country_example;  // string | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  (optional) 
            var language = language_example;  // string | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  (optional) 
            var notes = notes_example;  // string | Additional Customer Notes (optional) 

            try
            {
                // Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (Set a Delay before sending the First Feedback / Review Request)
                apiInstance.CreateCustomerAutomaticWithDelayReviewRequest(companyid, firstname, lastname, sendtype, delayBeforeFirstReviewRequest, email, mobile, address, zipcode, city, state, country, language, notes);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling CustomerApi.CreateCustomerAutomaticWithDelayReviewRequest: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 
 **firstname** | **string**| Customer First Name | 
 **lastname** | **string**| Customer Last Name | 
 **sendtype** | **string**| Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot;  | [default to 1]
 **delayBeforeFirstReviewRequest** | **string**| Delay before sending the first Feedback / Review Request (Allowed values: \&quot;immediately\&quot;, \&quot;X minute\&quot;, \&quot;X hour\&quot;, \&quot;X day\&quot;, \&quot;X week\&quot;, \&quot;X month\&quot;, \&quot;X year\&quot;)  | 
 **email** | **string**| Customer Email | [optional] 
 **mobile** | **string**| Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  | [optional] 
 **address** | **string**| Customer Postal Address | [optional] 
 **zipcode** | **string**| Customer Zipcode | [optional] 
 **city** | **string**| Customer City | [optional] 
 **state** | **string**| Customer State / Province / Region | [optional] 
 **country** | **string**| Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  | [optional] 
 **language** | **string**| Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  | [optional] 
 **notes** | **string**| Additional Customer Notes | [optional] 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="createcustomerimmediatefirstreviewrequest"></a>
# **CreateCustomerImmediateFirstReviewRequest**
> void CreateCustomerImmediateFirstReviewRequest (string companyid, string firstname, string lastname, string sendtype, string email, string mobile, string address, string zipcode, string city, string state, string country, string language, string notes)

Create a Customer AND Feedback / Review Requests

This API call creates a Customer in Reputation Builder AND Feedback / Review Request #1 (Email #1 AND/OR SMS #1 ONLY). Feedback / Review Request(s) are then sent immediately 

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class CreateCustomerImmediateFirstReviewRequestExample
    {
        public void main()
        {
            
            // Configure API key authorization: api_key
            Configuration.Default.ApiKey.Add("key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("key", "Bearer");

            var apiInstance = new CustomerApi();
            var companyid = companyid_example;  // string | Company ID
            var firstname = firstname_example;  // string | Customer First Name
            var lastname = lastname_example;  // string | Customer Last Name
            var sendtype = sendtype_example;  // string | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\"  (default to 1)
            var email = email_example;  // string | Customer Email (optional) 
            var mobile = mobile_example;  // string | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  (optional) 
            var address = address_example;  // string | Customer Postal Address (optional) 
            var zipcode = zipcode_example;  // string | Customer Zipcode (optional) 
            var city = city_example;  // string | Customer City (optional) 
            var state = state_example;  // string | Customer State / Province / Region (optional) 
            var country = country_example;  // string | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  (optional) 
            var language = language_example;  // string | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  (optional) 
            var notes = notes_example;  // string | Additional Customer Notes (optional) 

            try
            {
                // Create a Customer AND Feedback / Review Requests
                apiInstance.CreateCustomerImmediateFirstReviewRequest(companyid, firstname, lastname, sendtype, email, mobile, address, zipcode, city, state, country, language, notes);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling CustomerApi.CreateCustomerImmediateFirstReviewRequest: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 
 **firstname** | **string**| Customer First Name | 
 **lastname** | **string**| Customer Last Name | 
 **sendtype** | **string**| Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot;  | [default to 1]
 **email** | **string**| Customer Email | [optional] 
 **mobile** | **string**| Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  | [optional] 
 **address** | **string**| Customer Postal Address | [optional] 
 **zipcode** | **string**| Customer Zipcode | [optional] 
 **city** | **string**| Customer City | [optional] 
 **state** | **string**| Customer State / Province / Region | [optional] 
 **country** | **string**| Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  | [optional] 
 **language** | **string**| Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  | [optional] 
 **notes** | **string**| Additional Customer Notes | [optional] 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="createcustomermanualscheduleonereviewrequest"></a>
# **CreateCustomerManualScheduleOneReviewRequest**
> void CreateCustomerManualScheduleOneReviewRequest (string companyid, string firstname, string lastname, string sendtype, string emailnumber, string smsnumber, string scheduledate, string scheduletime, string email, string mobile, string address, string zipcode, string city, string state, string country, string language, string notes)

Create a Customer AND a one Feedback / Review Request (Manual Scheduling)

This API call creates a Customer in Reputation Builder AND one Feedback / Review Request. You decide which Feedback / Review Request # to send, the sending method (Email or SMS) and you have full control of the sending date and time 

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class CreateCustomerManualScheduleOneReviewRequestExample
    {
        public void main()
        {
            
            // Configure API key authorization: api_key
            Configuration.Default.ApiKey.Add("key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("key", "Bearer");

            var apiInstance = new CustomerApi();
            var companyid = companyid_example;  // string | Company ID
            var firstname = firstname_example;  // string | Customer First Name
            var lastname = lastname_example;  // string | Customer Last Name
            var sendtype = sendtype_example;  // string | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\"  (default to 1)
            var emailnumber = emailnumber_example;  // string | Set which Email Feedback / Requests will be sent (Allowed values: \"1\", \"2\", \"3\")  (default to 1)
            var smsnumber = smsnumber_example;  // string | Set which SMS Feedback / Requests will be sent (Allowed values: \"1\", \"2\", \"3\")  (default to 1)
            var scheduledate = scheduledate_example;  // string | Schedule date (yyyy/mm/dd) 
            var scheduletime = scheduletime_example;  // string | Schedule time (HH:MM 24 hours format) 
            var email = email_example;  // string | Customer Email (optional) 
            var mobile = mobile_example;  // string | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  (optional) 
            var address = address_example;  // string | Customer Postal Address (optional) 
            var zipcode = zipcode_example;  // string | Customer Zipcode (optional) 
            var city = city_example;  // string | Customer City (optional) 
            var state = state_example;  // string | Customer State / Province / Region (optional) 
            var country = country_example;  // string | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  (optional) 
            var language = language_example;  // string | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  (optional) 
            var notes = notes_example;  // string | Additional Customer Notes (optional) 

            try
            {
                // Create a Customer AND a one Feedback / Review Request (Manual Scheduling)
                apiInstance.CreateCustomerManualScheduleOneReviewRequest(companyid, firstname, lastname, sendtype, emailnumber, smsnumber, scheduledate, scheduletime, email, mobile, address, zipcode, city, state, country, language, notes);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling CustomerApi.CreateCustomerManualScheduleOneReviewRequest: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 
 **firstname** | **string**| Customer First Name | 
 **lastname** | **string**| Customer Last Name | 
 **sendtype** | **string**| Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot;  | [default to 1]
 **emailnumber** | **string**| Set which Email Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;)  | [default to 1]
 **smsnumber** | **string**| Set which SMS Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;)  | [default to 1]
 **scheduledate** | **string**| Schedule date (yyyy/mm/dd)  | 
 **scheduletime** | **string**| Schedule time (HH:MM 24 hours format)  | 
 **email** | **string**| Customer Email | [optional] 
 **mobile** | **string**| Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  | [optional] 
 **address** | **string**| Customer Postal Address | [optional] 
 **zipcode** | **string**| Customer Zipcode | [optional] 
 **city** | **string**| Customer City | [optional] 
 **state** | **string**| Customer State / Province / Region | [optional] 
 **country** | **string**| Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  | [optional] 
 **language** | **string**| Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  | [optional] 
 **notes** | **string**| Additional Customer Notes | [optional] 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deletecustomer"></a>
# **DeleteCustomer**
> void DeleteCustomer (string customerid)

Delete ONE Customer record

This API call deletes an existing Customer from Reputation Builder. It will also delete all Email / SMS Requests still in the Queue

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class DeleteCustomerExample
    {
        public void main()
        {
            
            // Configure API key authorization: api_key
            Configuration.Default.ApiKey.Add("key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("key", "Bearer");

            var apiInstance = new CustomerApi();
            var customerid = customerid_example;  // string | Customer ID

            try
            {
                // Delete ONE Customer record
                apiInstance.DeleteCustomer(customerid);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling CustomerApi.DeleteCustomer: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **customerid** | **string**| Customer ID | 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getallcustomersbycompanyid"></a>
# **GetAllCustomersBycompanyId**
> List<Customer> GetAllCustomersBycompanyId (string companyid)

Get Information on ALL Customers of a Company / Location / Feedback Page

This API call returns information from Reputation Builder on ALL existing Customers of a Company / Location / Feedback Page

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetAllCustomersBycompanyIdExample
    {
        public void main()
        {
            
            // Configure API key authorization: api_key
            Configuration.Default.ApiKey.Add("key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("key", "Bearer");

            var apiInstance = new CustomerApi();
            var companyid = companyid_example;  // string | Company ID

            try
            {
                // Get Information on ALL Customers of a Company / Location / Feedback Page
                List&lt;Customer&gt; result = apiInstance.GetAllCustomersBycompanyId(companyid);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling CustomerApi.GetAllCustomersBycompanyId: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 

### Return type

[**List<Customer>**](Customer.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getcustomerswhohavenotyetsubmittedreview"></a>
# **GetCustomersWhoHaveNotYetSubmittedReview**
> List<CustomerWhoHaveNotResponded> GetCustomersWhoHaveNotYetSubmittedReview (string companyid)

Get a list of Customers who have not yet submitted their Review / Feedback

This API call returns the list of Customers of a Company / Location / Feedback Page who have not yet responded to Feedback / Review Requests

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetCustomersWhoHaveNotYetSubmittedReviewExample
    {
        public void main()
        {
            
            // Configure API key authorization: api_key
            Configuration.Default.ApiKey.Add("key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("key", "Bearer");

            var apiInstance = new CustomerApi();
            var companyid = companyid_example;  // string | Company ID

            try
            {
                // Get a list of Customers who have not yet submitted their Review / Feedback
                List&lt;CustomerWhoHaveNotResponded&gt; result = apiInstance.GetCustomersWhoHaveNotYetSubmittedReview(companyid);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling CustomerApi.GetCustomersWhoHaveNotYetSubmittedReview: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 

### Return type

[**List<CustomerWhoHaveNotResponded>**](CustomerWhoHaveNotResponded.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getsinglecustomer"></a>
# **GetSingleCustomer**
> List<Customer> GetSingleCustomer (string customerid)

Get Information of ONE Customer

This API call returns information from Reputation Builder on ONE existing Customer

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetSingleCustomerExample
    {
        public void main()
        {
            
            // Configure API key authorization: api_key
            Configuration.Default.ApiKey.Add("key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("key", "Bearer");

            var apiInstance = new CustomerApi();
            var customerid = customerid_example;  // string | Customer ID

            try
            {
                // Get Information of ONE Customer
                List&lt;Customer&gt; result = apiInstance.GetSingleCustomer(customerid);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling CustomerApi.GetSingleCustomer: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **customerid** | **string**| Customer ID | 

### Return type

[**List<Customer>**](Customer.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updatecustomer"></a>
# **UpdateCustomer**
> void UpdateCustomer (string customerid, string firstname, string lastname, string notes, string email, string mobile, string address, string zipcode, string city, string state, string country, string language)

Update the record of ONE Customer

This API call updates information from Reputation Builder on ONE existing Customer

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class UpdateCustomerExample
    {
        public void main()
        {
            
            // Configure API key authorization: api_key
            Configuration.Default.ApiKey.Add("key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("key", "Bearer");

            var apiInstance = new CustomerApi();
            var customerid = customerid_example;  // string | Customer ID
            var firstname = firstname_example;  // string | Customer First Name
            var lastname = lastname_example;  // string | Customer Last Name
            var notes = notes_example;  // string | Additional Customer Notes
            var email = email_example;  // string | Customer Email (optional) 
            var mobile = mobile_example;  // string | Customer Mobile Phone (optional) 
            var address = address_example;  // string | Customer Postal Address (optional) 
            var zipcode = zipcode_example;  // string | Customer Zipcode (optional) 
            var city = city_example;  // string | Customer City (optional) 
            var state = state_example;  // string | Customer State / Province / Region (optional) 
            var country = country_example;  // string | Customer Country (optional) 
            var language = language_example;  // string | Customer Language (optional) 

            try
            {
                // Update the record of ONE Customer
                apiInstance.UpdateCustomer(customerid, firstname, lastname, notes, email, mobile, address, zipcode, city, state, country, language);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling CustomerApi.UpdateCustomer: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **customerid** | **string**| Customer ID | 
 **firstname** | **string**| Customer First Name | 
 **lastname** | **string**| Customer Last Name | 
 **notes** | **string**| Additional Customer Notes | 
 **email** | **string**| Customer Email | [optional] 
 **mobile** | **string**| Customer Mobile Phone | [optional] 
 **address** | **string**| Customer Postal Address | [optional] 
 **zipcode** | **string**| Customer Zipcode | [optional] 
 **city** | **string**| Customer City | [optional] 
 **state** | **string**| Customer State / Province / Region | [optional] 
 **country** | **string**| Customer Country | [optional] 
 **language** | **string**| Customer Language | [optional] 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

