using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IReviewSitesApi
    {
        /// <summary>
        /// Get all review sites of an account Get all review sites of an account
        /// </summary>
        /// <param name="username">User Name or Email address</param>
        /// <returns>List&lt;ReviewSites&gt;</returns>
        List<ReviewSites> GetAllReviewSitesByUserName (string username);
        /// <summary>
        /// Get all review sites of a company Get all review sites of a company
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <returns>List&lt;ReviewSites&gt;</returns>
        List<ReviewSites> GetAllReviewSitesBycompanyId (string companyid);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class ReviewSitesApi : IReviewSitesApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ReviewSitesApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public ReviewSitesApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="ReviewSitesApi"/> class.
        /// </summary>
        /// <returns></returns>
        public ReviewSitesApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Get all review sites of an account Get all review sites of an account
        /// </summary>
        /// <param name="username">User Name or Email address</param> 
        /// <returns>List&lt;ReviewSites&gt;</returns>            
        public List<ReviewSites> GetAllReviewSitesByUserName (string username)
        {
            
            // verify the required parameter 'username' is set
            if (username == null) throw new ApiException(400, "Missing required parameter 'username' when calling GetAllReviewSitesByUserName");
            
    
            var path = "/getAllReviewSitesByUserName";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (username != null) queryParams.Add("username", ApiClient.ParameterToString(username)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetAllReviewSitesByUserName: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetAllReviewSitesByUserName: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<ReviewSites>) ApiClient.Deserialize(response.Content, typeof(List<ReviewSites>), response.Headers);
        }
    
        /// <summary>
        /// Get all review sites of a company Get all review sites of a company
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <returns>List&lt;ReviewSites&gt;</returns>            
        public List<ReviewSites> GetAllReviewSitesBycompanyId (string companyid)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetAllReviewSitesBycompanyId");
            
    
            var path = "/getAllReviewSitesBycompanyId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetAllReviewSitesBycompanyId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetAllReviewSitesBycompanyId: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<ReviewSites>) ApiClient.Deserialize(response.Content, typeof(List<ReviewSites>), response.Headers);
        }
    
    }
}
