using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface ISentLogApi
    {
        /// <summary>
        /// Get company&#39;s sent log Get company&#39;s sent log
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <returns>List&lt;SentLog&gt;</returns>
        List<SentLog> GetSentLogByCompanyId (string companyid);
        /// <summary>
        /// Get a customerâ€™s sent log Get a customerâ€™s sent log
        /// </summary>
        /// <param name="customerid">Customer ID</param>
        /// <returns>List&lt;SentLog&gt;</returns>
        List<SentLog> GetSentLogByCustomerId (string customerid);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class SentLogApi : ISentLogApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="SentLogApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public SentLogApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="SentLogApi"/> class.
        /// </summary>
        /// <returns></returns>
        public SentLogApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Get company&#39;s sent log Get company&#39;s sent log
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <returns>List&lt;SentLog&gt;</returns>            
        public List<SentLog> GetSentLogByCompanyId (string companyid)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetSentLogByCompanyId");
            
    
            var path = "/getSentLogByCompanyId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetSentLogByCompanyId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetSentLogByCompanyId: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<SentLog>) ApiClient.Deserialize(response.Content, typeof(List<SentLog>), response.Headers);
        }
    
        /// <summary>
        /// Get a customerâ€™s sent log Get a customerâ€™s sent log
        /// </summary>
        /// <param name="customerid">Customer ID</param> 
        /// <returns>List&lt;SentLog&gt;</returns>            
        public List<SentLog> GetSentLogByCustomerId (string customerid)
        {
            
            // verify the required parameter 'customerid' is set
            if (customerid == null) throw new ApiException(400, "Missing required parameter 'customerid' when calling GetSentLogByCustomerId");
            
    
            var path = "/getSentLogByCustomerId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (customerid != null) queryParams.Add("customerid", ApiClient.ParameterToString(customerid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetSentLogByCustomerId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetSentLogByCustomerId: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<SentLog>) ApiClient.Deserialize(response.Content, typeof(List<SentLog>), response.Headers);
        }
    
    }
}
